@@ -8,6 +8,8 @@ use Socket;
 use Socket::Netlink qw( :DEFAULT );
 use Socket::Netlink::Route qw( :DEFAULT );
 
+use Data::Dump qw( pp );
+
 my $rtnlsock = IO::Socket::Netlink::Route->new
    or die "Cannot make netlink socket - $!";
 
@@ -33,9 +35,6 @@ foreach my $message ( @messages ) {
       printf "  type=%d index=%d flags=%04x change=%04x; rtattrs:\n",
          $message->ifi_type, $message->ifi_index, $message->ifi_flags, $message->ifi_change;
 
-      my $attrs = $message->nlattrs;
-      foreach my $name ( sort keys %$attrs ) {
-         printf "    %s => %s\n", $name, $attrs->{$name};
-      }
+      print pp( $message->nlattrs ) . "\n";
    }
 }
